import React from "react";
import { useMarkJs } from "../../../hooks/useMark";
import { useFuzzyResult } from "../../../hooks/useFuzzyResult";
/**
 * Renders indexed page section with higlighting using the mark.js hook.
 * @param curPage array of data that represents one page
 * @param onSelect function reference for what should happen when a result was chosen
 * @param inputVal val that should be used for marking via mark.js
 * @param searchResult original result
 * @param markOptions options from mark that should be applied.
 */
var ResultPage = function (_a) {
    var curPage = _a.curPage, onSelect = _a.onSelect, searchResult = _a.searchResult, inputVal = _a.inputVal, markOptions = _a.markOptions;
    var mark = useMarkJs(inputVal, markOptions).mark;
    var resultCountLabel = useFuzzyResult().resultCountLabel;
    //when page changes -> mark new page (mark needs a ref)
    var divRef = React.useRef(null);
    React.useEffect(function () {
        if (!divRef.current)
            return;
        mark(divRef.current, inputVal);
    }, [curPage]);
    return searchResult ? (React.createElement("div", { ref: divRef },
        React.createElement("h6", null,
            resultCountLabel,
            searchResult.length),
        curPage.map(function (val, ind) { return (React.createElement(React.Fragment, null,
            React.createElement("div", { className: "zim-fuzzy--result-div", key: "ResultPage_div_" + ind, style: { marginBottom: "28px" } },
                React.createElement("a", { className: "a_result", key: "searchable_" + ind, onClick: onSelect
                        ? function (evt) {
                            evt.preventDefault();
                            onSelect(val.item);
                        }
                        : undefined, href: val.item.value }, val.item.value),
                React.createElement("a", { href: val.item.value },
                    React.createElement("h3", { key: "paginatedHeader_" + ind }, val.item.label)),
                val.item.txt ? (React.createElement("p", { className: "zim-fuzzy--txt" }, val.item.txt)) : null,
                React.createElement("p", null, val.item.tags
                    ? val.item.tags.map(function (tag) { return (React.createElement("span", { className: "badge rounded-pill bg-light" }, tag)); })
                    : null)))); }))) : null;
};
export default ResultPage;
